reconstructCDSstart: Reconstruct CDS with alternate 5' exons

Description Usage Arguments Value Author(s) Examples

View source: R/old_secondary_modules.R

Description

This function will reconstruct a CDS sequence with a 5' end taken from a query transcript from the same gene

Usage

1
function(queryTranscript, refCDS, txrevise_out, fasta, full.output = FALSE)

Arguments

queryTranscript

A GRanges object containing exon structure of a query transcript from the same gene family

refCDS

A GRanges object containing reference CDS information of a gene family

fasta

Fasta sequence file

txrevise_out

Optional input. GRangesobject from 'indentifyAddedRemovedRegions()' or 'testTXforStart()' output. ?indentifyAddedRemovedRegions or ?testTXforStart for more information

full.output

if TRUE, function will output additional information

Value

Default output (ORF_considered), If reconstructed CDS contain an in-frame ATG, function will output a GRanges Object describing the reconstructed CDS. Else, function will output 'NA'

If full.output == TRUE, function will also return a list of GRanges objects similar to 'indentifyAddedRemovedRegions()' output (txrevise_out). ?indentifyAddedRemovedRegions for more information

Author(s)

Fursham Hamid

Examples

1
reconstructCDSstart(ptbp2Data$afCDS, ptbp2Data$refCDS, fasta = Ensembl_mm10)

fursham-h/ponder documentation built on Dec. 27, 2019, 12:15 a.m.